from .pilutil import *
from . import pilutil

__copyright__    = 'Copyright (C) 2023 kairi'
__version__      = '0.2.1'
__license__      = 'BSD-3-Clause'
__author__       = 'kairi'
__author_email__ = 'kairi.satellite@gmail.com'
__url__          = 'http://github.com/kairi003/scipy_pilutil'

__all__ = pilutil.__all__
